#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_REM_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_REM_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/rem.hpp>

#endif
